pub async fn new_sdio<'a, SDIO>(
state: &'a mut State,
sdio: SDIO,
firmware: &Aligned<A4, [u8]>,
nvram: &Aligned<A4, [u8]>,
) -> (NetDriver<'a>, Control<'a>, Runner<'a, SdioBus<SDIO>, Cyw43439>)where
SDIO: SdioBusCyw43<64>,👎Deprecated: please use
new_43439_sdio insteadExpand description
Create a new instance of the CYW43 driver.
Returns a handle to the network device, control handle and a runner for driving the low level stack.