cyw43

Crates

git

Versions

default

Flavors

JoinOptions

Struct JoinOptions 

#[non_exhaustive]
pub struct JoinOptions<'a> { pub auth: JoinAuth, pub cipher_tkip: bool, pub cipher_aes: bool, pub passphrase: &'a [u8], pub passphrase_is_prehashed: bool, }
Options for Control::join.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
auth: JoinAuth

Authentication type. Default Wpa2Wpa3.

cipher_tkip: bool

Enable TKIP encryption. Default false.

cipher_aes: bool

Enable AES encryption. Default true.

passphrase: &'a [u8]

Passphrase. Must contain between 8 and 64 bytes for an encrypted network. Default empty.

passphrase_is_prehashed: bool

If false, passphrase is the human-readable passphrase string. If true, passphrase is the result of applying the PBKDF2 hash to the passphrase string. This makes it possible to avoid storing unhashed passwords.

Pre-hashed passphrases must contain exactly 32 bytes and are not compatible with WPA3. Default false.

Implementations

Source

impl<'a> JoinOptions<'a>

pub fn new_open() -> Self

Create a new JoinOptions for joining open networks.

pub fn new(passphrase: &'a [u8]) -> Self

Create a new JoinOptions for joining encrypted networks.

Defaults to supporting WPA2+WPA3 with AES only, you may edit the returned options to change this.