#[non_exhaustive]pub struct JoinOptions<'a> {
pub auth: JoinAuth,
pub cipher_tkip: bool,
pub cipher_aes: bool,
pub passphrase: &'a [u8],
pub passphrase_is_prehashed: bool,
}Expand description
Options for Control::join.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.auth: JoinAuthAuthentication type. Default Wpa2Wpa3.
cipher_tkip: boolEnable TKIP encryption. Default false.
cipher_aes: boolEnable AES encryption. Default true.
passphrase: &'a [u8]Passphrase. Must contain between 8 and 64 bytes for an encrypted network. Default empty.
passphrase_is_prehashed: boolIf false, passphrase is the human-readable passphrase string.
If true, passphrase is the result of applying the PBKDF2 hash to the
passphrase string. This makes it possible to avoid storing unhashed passwords.
Pre-hashed passphrases must contain exactly 32 bytes and are not compatible with WPA3. Default false.
Implementations
Sourceimpl<'a> JoinOptions<'a>
impl<'a> JoinOptions<'a>